package Pcore::Handle::API::Google::Youtube;

use Pcore -role;

with qw[Pcore::Handle::API::Google::_Role];

1;
__END__
=pod

=encoding utf8

=cut
